@@ -2,16 +2,18 @@ package String::Template;
 
 use strict;
 use warnings;
-
+use 5.008001;
 use base 'Exporter';
 use POSIX;
 use Date::Parse;
 
+# ABSTRACT: Fills in string templates from hash of fields
+our $VERSION = '0.17'; # VERSION
+
+
 our @EXPORT = qw(expand_string missing_values expand_stringi);
 our @EXPORT_OK = qw(expand_hash);
 
-our $VERSION = '0.16';
-
 my %special =
 (
     '%' => sub { sprintf("%$_[0]", $_[1]) },
@@ -50,6 +52,7 @@ sub _replace
                                 : ($undef_flag ? "<$field>" : '');
 }
 
+
 #
 # expand_string($string, \%fields, $undef_flag)
 # find "<fieldname>"
@@ -63,6 +66,7 @@ sub expand_string
     return $string;
 }
 
+
 sub expand_stringi
 {
     my ($string, $fields, $undef_flag) = @_;
@@ -73,6 +77,7 @@ sub expand_stringi
     return $string;
 }
 
+
 sub missing_values
 {
     my ($string, $fields, $dont_allow_undefs) = @_;
@@ -86,6 +91,7 @@ sub missing_values
     return @missing;
 }
 
+
 sub expand_hash
 {
     my ($hash, $maxdepth) = @_;
@@ -97,31 +103,40 @@ sub expand_hash
 
     while ($changeflag)
     {    
-	$changeflag = 0;
-	$missing = 0;
-	foreach my $key (sort keys %$hash)
-	{
-	    my $newstr = expand_string($hash->{$key}, $hash, 1);
-	    
-	    if ($newstr ne $hash->{$key})
-	    {
-		$hash->{$key} = $newstr;
-		$changeflag = 1;
-	    }
-	    $missing++ if $newstr =~ /<[^>]+>/;
-	}
-	last unless --$maxdepth;
+        $changeflag = 0;
+        $missing = 0;
+        foreach my $key (sort keys %$hash)
+        {
+            my $newstr = expand_string($hash->{$key}, $hash, 1);
+            
+            if ($newstr ne $hash->{$key})
+            {
+                $hash->{$key} = $newstr;
+                $changeflag = 1;
+            }
+            $missing++ if $newstr =~ /<[^>]+>/;
+        }
+        last unless --$maxdepth;
     }
     return $missing ? undef : 1;
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 String::Template - Fills in string templates from hash of fields
 
+=head1 VERSION
+
+version 0.17
+
 =head1 SYNOPSIS
 
   use String::Template;
@@ -136,7 +151,13 @@ String::Template - Fills in string templates from hash of fields
 
 =head1 DESCRIPTION
 
-=head2 $str = expand_string($template, \%fields, $undef_flag).
+Generate strings based on a template.
+
+=head1 FUNCTIONS
+
+=head2 expand_string
+
+ my $str = expand_string($template, \%fields, $undef_flag);
 
 Fills in a simple template with values from a hash, replacing tokens
 like "<fieldname>" with the value from the hash $fields->{fieldname}.
@@ -164,12 +185,16 @@ it is false (default), undefined fields are simply replace with an
 empty string.  If set to true, the field is kept verbatim.  This can
 be useful for multiple expansion passes.
 
-=head2 $str = expand_stringi($template, \%fields, $undef_flag).
+=head2 expand_stringi
+
+ my $str = expand_stringi($template, \%fields, $undef_flag);
 
 expand_stringi works just like expand_string, except that tokens
 and hash keys are treated case insensitively.
 
-=head2 @missing = missing_values($template, \%fields, $dont_allow_undefs)
+=head2 missing_values
+
+ my @missing = missing_values($template, \%fields, $dont_allow_undefs);
 
 Checks to see if the template variables in a string template exist
 in a hash.  Set $dont_allow_undefs to 1 to also check to see if the
@@ -177,7 +202,9 @@ values for all such keys are defined.
 
 Returns a list of missing keys or an empty list if no keys were missing.
 
-=head2 $status = expand_hash($hash[, $maxdepth]);
+=head2 expand_hash
+
+ my $status = expand_hash($hash[, $maxdepth]);
 
 Expand a hash of templates/values.  This function will repeatedly
 replace templates in the values of the hash with the values of the
@@ -186,31 +213,30 @@ it has iterated $maxdepth times (default 10).
 
 Returns undef if there are unexpanded templates left, otherwise true.
 
-=head1 AUTHOR
-
-=over 4
-
-=item Current maintainer: Graham Ollis <plicease@cpan.org>
-
-=item Brian Duggan
-
-=item Curt Tilmes
-
-=item Jeremy Mates (thirg, JMATES)
-
-=back
-
 =head1 SEE ALSO
 
 L<String::Format> performs a similar function, with a different
 syntax.
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is cpyright 2015 by Brian Duggan
-
-This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
-
 =cut
 
+=head1 AUTHOR
 
+Original author: Brian Duggan
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Curt Tilmes
+
+Jeremy Mates (thirg, JMATES)
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Brian Duggan.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
